==> haskell-lpeg-1.1.0-35.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-lpeg.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lpeg
version:              1.1.0
visibility:           public
id:                   lpeg-1.1.0-4lkmrm9uJyD26csb1SJiMR
key:                  lpeg-1.1.0-4lkmrm9uJyD26csb1SJiMR
license:              MIT
copyright:
    © 2007-2019 Lua.org, PUC-Rio;
    © 2021-2023 Albert Krewinkel

maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             LPeg – Parsing Expression Grammars For Lua
description:
    This package contains the C sources of LPeg, as well
    as some tiny Haskell helper to load the package.

    <http://www.inf.puc-rio.br/~roberto/lpeg/>

category:             Foreign
abi:                  30ec10e26a227b8422c4763c25b8eb5f
exposed:              True
exposed-modules:      Lua.LPeg
import-dirs:          /usr/lib/ghc-9.6.6/site-local/lpeg-1.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/lpeg-1.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/lpeg-1.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lpeg
hs-libraries:         HSlpeg-1.1.0-4lkmrm9uJyD26csb1SJiMR
depends:              base-4.18.2.1 lua-2.3.3-8SYrA1CAYT85bngYHR6FzJ
haddock-interfaces:   /usr/share/doc/haskell-lpeg/html/lpeg.haddock
haddock-html:         /usr/share/doc/haskell-lpeg/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lpeg-1.1.0-36-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-lpeg.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lpeg
version:              1.1.0
visibility:           public
id:                   lpeg-1.1.0-EhMq0F1P2r14kE3k38rL9p
key:                  lpeg-1.1.0-EhMq0F1P2r14kE3k38rL9p
license:              MIT
copyright:
    © 2007-2019 Lua.org, PUC-Rio;
    © 2021-2023 Albert Krewinkel

maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             LPeg – Parsing Expression Grammars For Lua
description:
    This package contains the C sources of LPeg, as well
    as some tiny Haskell helper to load the package.

    <http://www.inf.puc-rio.br/~roberto/lpeg/>

category:             Foreign
abi:                  dbef0174a9d6b0fe18631163cb7ec5ae
exposed:              True
exposed-modules:      Lua.LPeg
import-dirs:          /usr/lib/ghc-9.6.6/site-local/lpeg-1.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/lpeg-1.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/lpeg-1.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lpeg
hs-libraries:         HSlpeg-1.1.0-EhMq0F1P2r14kE3k38rL9p
depends:              base-4.18.2.1 lua-2.3.3-DlJXYaKcRYH9BfYMQSRTd9
haddock-interfaces:   /usr/share/doc/haskell-lpeg/html/lpeg.haddock
haddock-html:         /usr/share/doc/haskell-lpeg/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
